@@ -11,24 +11,24 @@ fn block_text_embedding() {
 
 #[test]
 fn vertical() {
-    assert_parsed!("" vertical: [ ]);
+    assert_parsed!("<>" vertical: []);
 
-    assert_parsed!("+p{}" vertical: [
+    assert_parsed!("<+p{}>" vertical: [
         "+p{}" block_cmd: [_];
     ]);
 
-    assert_parsed!("#foo; #bar;" vertical: [
+    assert_parsed!("<#foo; #bar;>" vertical: [
         "#foo;" block_text_embedding: [_];
         "#bar;" block_text_embedding: [_];
     ]);
 
-    assert_parsed!("+p{}\n  #foo; %comment\n #bar;" vertical: [
+    assert_parsed!("<+p{}\n  #foo; %comment\n #bar;>" vertical: [
         "+p{}" block_cmd: [_];
         "#foo;" block_text_embedding: [_];
         "#bar;" block_text_embedding: [_];
     ]);
 
-    assert_parsed!("+p{}\n  #foo; +section<%comment\n #bar;>" vertical: [
+    assert_parsed!("<+p{}\n  #foo; +section<%comment\n #bar;>>" vertical: [
         "+p{}" block_cmd: [_];
         "#foo;" block_text_embedding: [_];
         "+section<%comment\n #bar;>" block_cmd: [_];
